@@ -2,7 +2,7 @@ package Net::DNS::RR::RRSIG;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: RRSIG.pm 1972 2024-04-21 08:13:19Z willem $)[2];
+our $VERSION = (qw$Id: RRSIG.pm 1990 2024-09-18 13:16:07Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -72,6 +72,7 @@ sub _format_rdata {			## format rdata portion of RR string.
 	my $signame = $self->{signame};
 	my @sig64   = split /\s+/, MIME::Base64::encode( $self->sigbin );
 	my @rdata   = ( map( { $self->$_ } @field ), $signame->string, @sig64 );
+	$rdata[3] .= "\n";
 	return @rdata;
 }
 
@@ -841,6 +842,6 @@ L<RFC4034(3)|https://iana.org/go/rfc4034#section-3>
 
 L<Algorithm Numbers|https://iana.org/assignments/dns-sec-alg-numbers>
 
-L<BIND Administrator Reference Manual|https://bind.isc.org/>
+L<BIND Administrator Reference Manual|https://bind9.readthedocs.io/en/latest/>
 
 =cut
